#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.unihedron.com/projects/gonvert/index.php
# source           : http://www.unihedron.com/projects/gonvert/downloads/gonvert-0.2.19.tar.gz

# Package name
NAME="gonvert"
# Package version
VERSION="0.2.19"
# Source code URL
SOURCE="http://www.unihedron.com/projects/gonvert/downloads/gonvert-0.2.19.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="doc/*"


CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="noarch"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: gonvert is a unit conversion utility
$NAME:
$NAME: gonvert is a conversion utility that allows conversion between many
$NAME: units like CGS, Ancient, Imperial with many categories like length,
$NAME: mass, numbers, etc. All units converted values shown at once as you
$NAME: type. Easy to add/change your own units.
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Change original destination of /usr/local to /usr
cd $NAME-$VERSION
sed -i -e 's,/usr/local,/usr,' Makefile

# Install on temporary directory
make install DESTDIR=$PKG

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION
rm -rf $PKG/usr/share/doc

# Copy the application icon to the right place
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps/
cp -a $CWD/$NAME-$VERSION/pixmaps/gonvert.png $PKG/usr/share/icons/hicolor/48x48/apps/
# Remove the extra icons
rm -rf $PKG/usr/share/pixmaps/gonvert-icon_alternative.png

# Create the .desktop file
mkdir -p $PKG/usr/share/applications
cp $CWD/$NAME-$VERSION/gonvert.desktop $PKG/usr/share/applications
rm -rf $PKG/usr/share/gnome
sed -i -e 's/.png//' $PKG/usr/share/applications/gonvert.desktop

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
